// Modified from https://www.shadertoy.com/view/4djGDy

precision highp float;

varying vec2 fragCoord;
uniform vec3 iResolution;
uniform sampler2D iChannel0;
uniform float iTime;

const float bands = 20.0;
const float colorRange = 0.3; // >0. (=1. full color range, >1. repeat colors)


//convert HSV to RGB
vec3 hsv2rgb(vec3 c){
    vec4 K = vec4(1.0, 2.0 / 3.0, 1.0 / 3.0, 3.0);
    vec3 p = abs(fract(c.xxx + K.xyz) * 6.0 - K.www);
    return c.z * mix(K.xxx, clamp(p - K.xxx, 0.0, 1.0), c.y);
}


void main()
{
    // middle = (0/0)
    vec2 k = fragCoord.xy - .5;


    float dis = distance(k , vec2(0));

    //degree from bottom 0 and top 1.0.  /left right symetric and approximated by "bands"
    float deg = acos(k.y/dis)/3.14;
    deg = 1.-floor(deg*bands)/bands;


   //colorwheel, dark in the middle, changing colors over time
    vec3 color = hsv2rgb(  vec3( deg*colorRange + iTime*0.07 , 1.0 , smoothstep(0.0, 0.6, dis) )  );



	//brightness of a band by fourier (degree to frequency / magnitude to brightness)
    float bandBrightness = texture2D( iChannel0, vec2(deg,0.25)).x;


    //more blinky blinky x^2
    color*=bandBrightness*bandBrightness;

    //brighter
    color*=4.;

    //dark point in the middle
    //color *=smoothstep(0.11, 0.26, dis);


	//return
    gl_FragColor = vec4(color, 0.0);
}